.. coworker documentation master file, created by
   sphinx-quickstart on Wed Sep 14 23:22:00 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to coworker's documentation!
====================================

Contents:

.. toctree::
   :maxdepth: 2

   README

API Documentation
=================

.. toctree::
   :maxdepth: 2

   api/coworker

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

